<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ne">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>आयरनीन मोड सक्रिय</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>आयरनीन मोड असक्रिय</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>अक्रिय गर्न</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>क्रिय गर्न</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>आयरनीन मोड</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>आयरनीन मोड सेटिङहरू</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>आयरनीन मोड</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>माई डेविस्न</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>ब्लूटूथ सेटिङहरू</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>कुनैही बाहिर छ</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>कुनैही बाहिर गर्न</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>कुनैही भएको गर्न</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>ब्लूटूथ सेटिङहरू</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 संयुक्त छ</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>संयुक्त गर्दैको...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>ब्लुटूथ</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>कुनैही बाहिर छ</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>%1 संयुक्त छ</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>संयुक्त छैन</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>बाहिर</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>ब्लुटूथ</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>लाम्बीता</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>प्रदर्शन सेटिङहरू</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>प्रदर्शन सेटिङहरू</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>लाम्बीता</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>सूर्य</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>मङ्दावस</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>बुधवास</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>बीविषावस</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>गुरुवास</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>शुक्रवास</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>शनिवास</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>कीबोर्ड थप्नुहोस्</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>मिति समय</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>दशमिक वेळ</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>बीसमिक वेळ</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>समय सेटिङहरू</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>कैलेंडर खोल्नुहोस्</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>सोमबार</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>मंगलबार</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>बुधबार</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>बिहिबार</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>शुक्रबार</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>शनिबार</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>आइतबार</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>मङ्दावस</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>बुधवास</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>बीविषावस</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>गुरुवास</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>शुक्रवास</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>शनिवास</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>रविवास</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>अन्य यस्ताहरू</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>DND वर्णन</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>DND वर्णन सेटिङहरू</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>काम गर्नुहोस्</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>काम गर्नुहोस्</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>DND वर्णन खुलिएको</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>DND वर्णन बनाउँदैको</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>DND वर्णन</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>कुराकानी सुरक्षा</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>कुराकानी सुरक्षा खोलिएको</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>कुराकानी सुरक्षा बन्द गरिएको</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>प्रदर्शन सेटिङहरू</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>कुराकानी सुरक्षा</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>थीम</translation>
    </message>
    <message>
        <source>On</source>
        <translation>कोडलाई खोल्नुहोस्</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>कोडलाई बन्द गर्नुहोस्</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>सफाई</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>सूनी</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>अटोमेटिक</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>कुराकानी सुरक्षाको बन्द</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>कुराकानी सुरक्षाको खोल</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>प्रदर्शन सेटिङहरू</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>थीम: सफाई</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>थीम: सूनी</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>थीम: अटोमेटिक</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>भावको प्रभाव</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>सफाई</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>सूनी</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>अटोमेटिक</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>थीम</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>न कुनै संदेश</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>संदेश सेटिङहरू</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>नोटिफिकेशन</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>DND राउंड बाउट बाट्नेको बनाउनुहोस्</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>DND राउंड बाउट बाट्नेको खोल्नुहोस्</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>नोटिफिकेशन</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>अन-बोर्ड</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>सेटिंग्स</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>उच्च प्रदर्शन</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>समान्तराल</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>शक्ति संकरका</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>प्रदर्शन समान्तराल</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>शक्ति</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>पावर सेटिङहरू</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>क्षमता %1, %2मिनट बाँकी</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>क्षमता %1, %2 घंटा  %3 मिनट बाँकी</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>%1 मा चार्ज  हुंदै, पुर्ण हुन %2 मिनट लाग्छ</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>%1 मा चार्ज हुंदै, पुर्ण हुन %2 घण्टा %3 मिनट लाग्छ</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>%1 क्यापासिटी</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>चार्ज गर्दै% 1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>%1 क्यापासिटी ... राख्नुहोस्</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>%1 क्यापासिटी, पूर्ण बाटिएको</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>%1 क्यापासिटी, बाटिनभएको छैन</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>बैटरी</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>बाटिन्थ्याबाट आकलन गर्ने अवधि गणना गर्दै चल्दैछ</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>प्रयोग थपी विटको अवधि गणना गर्दै चल्दैछ</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>%1 मिनिट थपी छ</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>%1 घण्टा %2 मिनिट थपी छ</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>बाटिनभएको छैन</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>पूर्ण बाटिएको</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>बाटिन्थ्याबाट %1 मिनिट तक बाटिएको</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>बाटिन्थ्याबाट %1 घण्टा %2 मिनिट तक बाटिएको</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>%1 क्यापासिटी, %2 घण्टा थपी छ</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 घण्टा थपी छ</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>%1 बाटिन्थ्याबाट %2 घण्टा तक बाटिएको</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>चालन, %1 गण्ड तक सम्पूर्ण</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>गान</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>जानकारिहीन</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>बन्द गर्नुहोस्</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>निलम्बन गर्नुहोस्</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>हाइबर्नेट</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>लक</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>बाहिर निस्कनुहोस्</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>पावर सेटिङहरू</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>रिबुट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>अद्यापित गर्नुहोस् र बंद गर्नुहोस्</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>अद्यापित गर्नुहोस् र रीस्टार्ट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>बंद गर्नुहोस्</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>सदस्ता बदल्नुहोस्</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>आज</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>लूनार</translation>
    </message>
    <message>
        <source>y</source>
        <translation>साल</translation>
    </message>
    <message>
        <source>m</source>
        <translation>महिना</translation>
    </message>
    <message>
        <source>d</source>
        <translation>दिन</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Jan</source>
        <translation>जनवरी</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>फेब्रुवारी</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>मार्च</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>एप्रिल</translation>
    </message>
    <message>
        <source>May</source>
        <translation>मई</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>जुन</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>जुलाई</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>अगस्त</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>सितम्बर</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>अक्टोबर</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>नवम्बर</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>दिसम्बर</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>कालेंदर खोल्नुहोस्</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>मुंदेरो</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>तिहरो</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>बेछरो</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>बिहरो</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>पगुहरो</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>शुक्रवार</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>वैन्दै</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>वॉक्योम</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>आउटपुट</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>सोन्ड सेटिङस</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>ध्वनि/आवाज</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>म्युट बाँको</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>म्युट</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>सोन्ड सेटिङस</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>आउटपुट डाइवाइस छैन</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>वॉक्योम %1</translation>
    </message>
</context>
</TS>